@@ -23,10 +23,12 @@
 #include "config.h"
 #include <cstdio>
 #include <cstring>
-#include <iostream.h>
+#include <iostream>
 #include <stdlib.h>
 #include "afi.hh"
 
+using namespace std;
+
 AddressFamily::AddressFamily(void) :
   afi(NULL)
 {
@@ -43,8 +45,7 @@ AddressFamily::AddressFamily(const AddressFamily &p) :
 }
 
 bool AddressFamily::is_Matching(char *name)  {
-  if (strncasecmp (name, afi, sizeof(afi)) == 0 
-   && strncasecmp (name, afi, sizeof(name)) == 0)
+  if (strcasecmp (name, afi) == 0) 
      return 1;
   return 0; 
 }
@@ -62,7 +63,7 @@ bool AddressFamily::is_ipv6() {
 }
 
 bool AddressFamily::is_default() {
-  if ((strcmp(afi, "ipv4") == 0) || (strcmp(afi, "ipv4.unicast") == 0))
+  if (strcmp(afi, "ipv4.unicast") == 0)
      return true;
   return false;
 } 
